/*
package com.dxhy.core.job.dao;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dxhy.core.job.bxvo.ControlRulesInvoiceRequest;
import com.dxhy.core.job.bxvo.EnterpriseInfoConfigEntity;
import com.dxhy.core.job.bxvo.EnterpriseInfoEntity;
import com.dxhy.core.job.entity.TAcOrg;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

@Mapper
public interface EnterpriseControlRulesDao extends BaseMapper<EnterpriseInfoEntity> {

    //查询所需要对接规则引擎的税号信息
    List<TAcOrg> getTaxNo();

    //查询所需要对接的增值税发票信息数量
    int vatInvoiceSum(Map<String, Object> pramsMap);

    List<ControlRulesInvoiceRequest> vatInvoice(Map<String, Object> pramsMap);

    //更新增值税发票信息
    void updateVatInvoice(@Param("uuid") String uuid);

    //获取税号对应规则引擎数据信息
    EnterpriseInfoConfigEntity selectConfig(@Param("taxNo") String taxNo,@Param("type")String type);

    int notInvoiceSum(Map<String, Object> pramsMap);

    List<ControlRulesInvoiceRequest> notInvoice(Map<String, Object> pramsMap);
    void updateNotInvoice(@Param("uuid") String uuid);

}
*/
